@@ -7,7 +7,7 @@ use Carp qw(confess);
 
 use XSLoader;
 BEGIN {
-    our $VERSION = '1.0404';
+    our $VERSION = '1.0501';
     XSLoader::load;
 }
 
@@ -417,6 +417,10 @@ L<parameter list|/"Parameter list">. To specify a prototype, put it as the
 first attribute (e.g. C<fun foo :(&$$)>). This is syntactically unambiguous
 because normal L<attributes|/Attributes> need a name after the colon.
 
+You can also use an attribute named C<prototype> (e.g.
+C<fun foo :prototype(&$$)>). In that case it does not have to be the first
+attribute. This syntax is also compatible with C<sub> in perl 5.20 and newer.
+
 =head3 Parameter list
 
 The parameter list is a list of variables enclosed in parentheses, except it's
@@ -455,9 +459,9 @@ passed in:
 =item 3. Optional positional parameters
 
 Parameters can be marked as optional by putting an equals sign (C<=>) and an
-expression (the "default argument") after them. If no corresponding argument is
-passed in by the caller, the default argument will be used to initialize the
-parameter:
+(optional) expression (the "default argument") after them. If no corresponding
+argument is passed in by the caller, the default argument will be used to
+initialize the parameter:
 
   fun scale($base, $factor = 2) {
     return $base * $factor;
@@ -466,6 +470,10 @@ parameter:
   say scale(3, 5);  # "15"
   say scale(3);     # "6"
 
+Using just a C<=> with no expression after is equivalent to specifying
+C<= undef>, i.e. the corresponding parameter is optional and has a default
+value of C<undef>.
+
 The default argument is I<not> cached. Every time a function is called with
 some optional arguments missing, the corresponding default arguments are
 evaluated from left to right. This makes no difference for a value like C<2>
@@ -525,7 +533,8 @@ parameters come first:
 =item 5. Optional named parameters
 
 As with positional parameters, you can make named parameters optional by
-specifying a default argument after an equals sign (C<=>):
+specifying a default argument (or nothing, which is equivalent to C<undef>)
+after an equals sign (C<=>):
 
   fun rectangle(:$width, :$height, :$color = "chartreuse") {
     ...
